@@ -26,7 +26,7 @@ typedef Eo Efl_Ui_Table_Static;
  */
 #define EFL_UI_TABLE_STATIC_CLASS efl_ui_table_static_class_get()
 
-EWAPI const Efl_Class *efl_ui_table_static_class_get(void) EINA_CONST;
+EAPI EAPI_WEAK const Efl_Class *efl_ui_table_static_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
