@@ -25,7 +25,7 @@ typedef Eo Efl_Canvas_Snapshot;
  */
 #define EFL_CANVAS_SNAPSHOT_CLASS efl_canvas_snapshot_class_get()
 
-EWAPI const Efl_Class *efl_canvas_snapshot_class_get(void) EINA_CONST;
+EVAS_API EVAS_API_WEAK const Efl_Class *efl_canvas_snapshot_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
